@@ -14,7 +14,6 @@ See L<Siebel::Srvrmgr::ListParser::Output>.
 
 use Moose;
 use Siebel::Srvrmgr::Regexes;
-use feature 'switch';
 
 extends 'Siebel::Srvrmgr::ListParser::Output';
 
@@ -60,14 +59,15 @@ has 'patch' =>
 
 =head2 copyright
 
-An array reference that represents the copyright information of the Siebel enterprise where the connection was stablished. This is a read-only attribute.
+A string that represents the copyright information of the Siebel enterprise where the connection was stablished. This is a read-only attribute.
 
 =cut
 
 has 'copyright' => (
     is     => 'ro',
-    isa    => 'ArrayRef[Str]',
-    reader => 'get_copyright'
+    isa    => 'Str',
+    reader => 'get_copyright',
+    writer => '_set_copyright'
 );
 
 =pod
@@ -102,21 +102,6 @@ has 'total_connected' => (
 
 =pod
 
-=head2 help
-
-A string representing how to invoke online help within C<srvrmgr> program. This is a read-only attribute.
-
-=cut
-
-has 'help' => (
-    is     => 'ro',
-    isa    => 'Str',
-    reader => 'get_help',
-    writer => '_set_help'
-);
-
-=pod
-
 =head2 field_pattern
 
 This attribute makes no sense for Greetings class, there it will always be equal C<undef>.
@@ -161,20 +146,14 @@ sub parse {
 
     my $hello_regex = Siebel::Srvrmgr::Regexes::CONN_GREET;
 
-    my $is_copyright = 0;
-
     foreach my $line ( @{$data_ref} ) {
 
         chomp($line);
+        next if $line eq '';
 
-        given ($line) {
+      SWITCH: {
 
-            when ('') {
-
-                # do nothing
-            }
-
-            when (/$hello_regex/) {
+            if ( $line =~ /$hello_regex/ ) {
 
 #Siebel Enterprise Applications Siebel Server Manager, Version 7.5.3 [16157] LANG_INDEPENDENT
                 my @words = split( /\s/, $line );
@@ -183,24 +162,20 @@ sub parse {
                 $words[8] =~ tr/[]//d;
                 $self->_set_patch( $words[8] );
 
+                last SWITCH;
+
             }
 
-            when (/^Copyright/) {
+            if ( $line =~ /^Copyright/ ) {
 
                 #Copyright (c) 2001 Siebel Systems, Inc.  All rights reserved.
+
                 $self->_set_copyright($line);
-                $is_copyright = 1;
 
+                last SWITCH;
             }
 
-            when (/^Type\s\"help\"/) {
-
-                $self->_set_help($line);
-                $is_copyright = 0;
-
-            }
-
-            when (/^Connected/) {
+            if ( $line =~ /^Connected/ ) {
 
        #Connected to 1 server(s) out of a total of 1 server(s) in the enterprise
        #Connected to 2 server(s) out of a total of 2 server(s) in the enterprise
@@ -209,18 +184,7 @@ sub parse {
                 $self->_set_total_servers( $words[9] );
                 $self->_set_total_conn( $words[2] );
 
-            }
-
-            when (/^[\w\(]+/) {
-
-                $self->_set_copyright($line) if ($is_copyright);
-
-            }
-
-            default {
-
-                die 'Invalid data from line [' . $line . ']';
-
+                last SWITCH;
             }
 
         }
@@ -231,25 +195,6 @@ sub parse {
 
 =pod
 
-=head2 _set_copyright
-
-"Private" method to set the copyright information.
-
-=cut
-
-sub _set_copyright {
-
-    my $self = shift;
-    my $line = shift;
-
-    push( @{ $self->{copyright} }, $line );
-
-    return 1;
-
-}
-
-=pod
-
 =head1 SEE ALSO
 
 =over 2
@@ -264,29 +209,6 @@ L<Siebel::Srvrmgr::ListParser::Output>
 
 =back
 
-=head1 AUTHOR
-
-Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
-
-This file is part of Siebel Monitoring Tools.
-
-Siebel Monitoring Tools is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Siebel Monitoring Tools is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Siebel Monitoring Tools.  If not, see <http://www.gnu.org/licenses/>.
-
 =cut
 
 no Moose;
