@@ -12,7 +12,6 @@ use Moose;
 use MooseX::Storage;
 use namespace::autoclean;
 use Siebel::Srvrmgr::ListParser::Output::ListComp::Comp;
-use Carp;
 
 =pod
 
@@ -141,9 +140,6 @@ sub get_comp_data {
     my $self  = shift;
     my $alias = shift;
 
-    confess 'Must give a valid value to alias parameter'
-      unless ( defined($alias) );
-
     if ( exists( $self->get_data()->{$alias} ) ) {
 
         my $comp_ref = $self->get_data()->{$alias};
@@ -184,29 +180,6 @@ L<Siebel::Srvrmgr::ListParser::Output::ListComp::Comp>
 
 =back
 
-=head1 AUTHOR
-
-Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>.
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>.
-
-This file is part of Siebel Monitoring Tools.
-
-Siebel Monitoring Tools is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Siebel Monitoring Tools is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Siebel Monitoring Tools.  If not, see L<http://www.gnu.org/licenses/>.
-
 =cut
 
 __PACKAGE__->meta->make_immutable;
