@@ -9,7 +9,6 @@ Siebel::Srvrmgr::ListParser::Output::ListCompDef - subclass to parse component d
 =cut
 
 use Moose;
-use feature 'switch';
 
 extends 'Siebel::Srvrmgr::ListParser::Output';
 
@@ -98,9 +97,9 @@ sub parse {
 
         chomp($line);
 
-        given ($line) {
+      SWITCH: {
 
-            when ( $line =~ /^\-+\s/ ) {    # this is the header line
+            if ( $line =~ /^\-+\s/ ) {    # this is the header line
 
                 my @columns = split( /\s{2}/, $line );
 
@@ -116,38 +115,38 @@ sub parse {
 
                 $self->_set_fields_pattern($pattern);
 
+                last SWITCH;
+
             }
 
-            when (/^CC_NAME\s.*\sCC_INCARN_NO\s*$/) {    # this is the header
+            if ( $line eq '' ) {
+
+                last SWITCH;
+
+            }
+
+            if ( $line =~ /^CC_NAME\s.*\sCC_INCARN_NO\s*$/ ) { # this is the header
 
                 my @columns = split( /\s{2,}/, $line );
 
                 $self->set_comp_defs( \@columns );
 
-            }
-
-            when ('') {
-
-                # do nothing
+                last SWITCH;
 
             }
-
-            default {
+            else {
 
                 my @fields_values;
 
-                if ( $self->get_fields_pattern() ) {
+				if ($self->get_fields_pattern()) {
+				
+                  @fields_values = unpack( $self->get_fields_pattern(), $line );
+				
+				} else {
 
-                    @fields_values =
-                      unpack( $self->get_fields_pattern(), $line );
+					die "Cannot continue since fields pattern was not defined\n";
 
-                }
-                else {
-
-                    die
-                      "Cannot continue since fields pattern was not defined\n";
-
-                }
+				}
 
                 my $cc_name = $fields_values[0];
 
@@ -155,9 +154,6 @@ sub parse {
 
                 my $columns_ref = $self->get_comp_defs();
 
-                confess "Cannot continue without defining fields names"
-                  unless ( defined($columns_ref) );
-
                 if (@fields_values) {
 
                     for ( my $i = 0 ; $i < $list_len ; $i++ ) {
@@ -170,7 +166,7 @@ sub parse {
                 }
                 else {
 
-                    die 'Could not parse line [' . $line . ']';
+                    warn "got nothing\n";
 
                 }
 
@@ -201,29 +197,6 @@ L<Moose>
 
 =back
 
-=head1 AUTHOR
-
-Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
-
-This file is part of Siebel Monitoring Tools.
-
-Siebel Monitoring Tools is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Siebel Monitoring Tools is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Siebel Monitoring Tools.  If not, see <http://www.gnu.org/licenses/>.
-
 =cut
 
 no Moose;
