@@ -1,7 +1,6 @@
 package Test::Server;
 
 use Test::Most;
-use Test::Moose qw(has_attribute_ok);
 use base 'Test::Class';
 use Siebel::Srvrmgr::ListParser::Output::ListComp;
 
@@ -13,7 +12,7 @@ sub startup : Tests(startup => 1) {
     use_ok $test->class;
 }
 
-sub constructor : Tests(10) {
+sub constructor : Tests(6) {
 
     my $test  = shift;
     my $class = $test->class;
@@ -40,9 +39,6 @@ sub constructor : Tests(10) {
         '... and the constructor should succeed'
     );
 
-    has_attribute_ok( $server, 'name' );
-    has_attribute_ok( $server, 'data' );
-
     isa_ok( $server, $class, '... and the object it returns' );
 
     is( $server->get_name(), 'foobar', 'get_name returns the correct value' );
@@ -53,12 +49,6 @@ sub constructor : Tests(10) {
         'get_comp returns a Comp object'
     );
 
-    isa_ok( $server->get_comps(), 'ARRAY',
-        'get_comps returns an array reference' );
-
-    isa_ok( $server->get_comp_data('EIM'),
-        'HASH', 'get_comp_data returns an hash reference' );
-
 }
 
 1;
